==> Paws-0.16.tar.gz: Paws-0.16/lib/Paws/EC2/MoveAddressToVpc.pm <==

package Paws::EC2::MoveAddressToVpc;
  use Moose;
  has DryRun => (is => 'ro', isa => 'Bool', traits => ['NameInRequest'], request_name => 'dryRun' );
  has PublicIp => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'publicIp' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'MoveAddressToVpc');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::MoveAddressToVpcResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::MoveAddressToVpc - Arguments for method MoveAddressToVpc on Paws::EC2

=head1 DESCRIPTION

This class represents the parameters used for calling the method MoveAddressToVpc on the 
Amazon Elastic Compute Cloud service. Use the attributes of this class
as arguments to method MoveAddressToVpc.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to MoveAddressToVpc.

As an example:

  $service_obj->MoveAddressToVpc(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 DryRun => Bool

  

Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.










=head2 B<REQUIRED> PublicIp => Str

  

The Elastic IP address.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method MoveAddressToVpc in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.17.tar.gz: Paws-0.17/lib/Paws/EC2/MoveAddressToVpc.pm <==

package Paws::EC2::MoveAddressToVpc;
  use Moose;
  has DryRun => (is => 'ro', isa => 'Bool', traits => ['NameInRequest'], request_name => 'dryRun' );
  has PublicIp => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'publicIp' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'MoveAddressToVpc');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::MoveAddressToVpcResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::MoveAddressToVpc - Arguments for method MoveAddressToVpc on Paws::EC2

=head1 DESCRIPTION

This class represents the parameters used for calling the method MoveAddressToVpc on the 
Amazon Elastic Compute Cloud service. Use the attributes of this class
as arguments to method MoveAddressToVpc.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to MoveAddressToVpc.

As an example:

  $service_obj->MoveAddressToVpc(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 DryRun => Bool

  Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.

=head2 B<REQUIRED> PublicIp => Str

  The Elastic IP address.



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method MoveAddressToVpc in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
